pub enum OrderEvent {
Unfilled {
id: u128,
},
Placed {
id: u128,
},
Canceled {
id: u128,
},
PartiallyFilled {
id: u128,
filled_qty: u64,
fills: Vec<FillMetadata>,
},
Filled {
id: u128,
filled_qty: u64,
fills: Vec<FillMetadata>,
},
}Expand description
An event resulting from the execution of an order.
Variants
Unfilled
Indicating that the corresponding order was not filled. It is only sent in response to market orders.
Placed
Indicating that the corresponding order was placed on the order book. It is only send in response to limit orders.
Canceled
Indicating that the corresponding order was removed from the order book. It is only sent in response to cancel orders.
PartiallyFilled
Indicating that the corresponding order was only partially filled. It is sent in response to market or limit orders.
Fields

fills: Vec<FillMetadata>A vector with information on the order fills.
Filled
Indicating that the corresponding order was filled completely. It is sent in response to market or limit orders.